# PyNyzo tests

Run `pytest -v`

Some tests can also be run with partial tests but more verbose output like `python3 test_ed25519.py`

## So far...

- basic message encoding/decoding
- key generation and display format

## Tests, but not part of test suite

`get_status.py` is a test script to fetch status from a node.    
See `python3 get_status.py -h` for help
